﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Net;
using System.IO;

namespace TestLoginWin.AppCode
{
    /// <summary>
    /// 访问WEB页面
    /// </summary>
    /// <author>Jailu</author>
    /// <date>May 10, 2008</date>
    public class HttpHelper
    {
        #region 私有变量
        private CookieContainer cc;
        private string contentType = "application/x-www-form-urlencoded";
        private string accept = "text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5";
        private string userAgent = "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.14) Gecko/20080404 Firefox/2.0.0.14";
        #endregion

        #region 属性
        public CookieContainer CookieContainer
        {
            get
            {
                return cc;
            }
        }
        #endregion

        #region 构造函数
        public HttpHelper()
        {
            cc = new CookieContainer();
        }

        public HttpHelper(CookieContainer cc)
        {
            this.cc = cc;
        }

        public HttpHelper(string contentType, string accept, string userAgent)
        {
            this.contentType = contentType;
            this.accept = accept;
            this.userAgent = userAgent;
        }

        public HttpHelper(CookieContainer cc, string contentType, string accept, string userAgent)
        {
            this.cc = cc;
            this.contentType = contentType;
            this.accept = accept;
            this.userAgent = userAgent;
        }
        #endregion

        #region 公共方法
        public string GetHtml(string url, string postData, Method method, out CookieCollection cookieCollection)
        {
            if (string.IsNullOrEmpty(postData))
            {
                return GetHtml(url, out cookieCollection);
            }

            byte[] byteRequest = Encoding.Default.GetBytes(postData);

            HttpWebRequest httpWebRequest;
            httpWebRequest = (HttpWebRequest)HttpWebRequest.Create(url);

            httpWebRequest.CookieContainer = cc;
            httpWebRequest.ContentType = contentType;
            httpWebRequest.Referer = url;
            httpWebRequest.Accept = accept;
            httpWebRequest.UserAgent = userAgent;
            httpWebRequest.Method = method == Method.POST ? "POST" : "GET";
            httpWebRequest.ContentLength = byteRequest.Length;

            Stream stream = httpWebRequest.GetRequestStream();
            stream.Write(byteRequest, 0, byteRequest.Length);
            stream.Close();

            HttpWebResponse httpWebResponse;
            httpWebResponse = (HttpWebResponse)httpWebRequest.GetResponse();
            Stream responseStream = httpWebResponse.GetResponseStream();
            StreamReader streamReader = new StreamReader(responseStream, Encoding.UTF8);
            string html = streamReader.ReadToEnd();
            streamReader.Close();
            responseStream.Close();

            cookieCollection = cc.GetCookies(new Uri(url));

            return html;
        }

        public string GetHtml(string url, out CookieCollection cookieCollection)
        {
            HttpWebRequest httpWebRequest;

            httpWebRequest = (HttpWebRequest)HttpWebRequest.Create(url);
            httpWebRequest.CookieContainer = cc;

            HttpWebResponse httpWebResponse;
            httpWebResponse = (HttpWebResponse)httpWebRequest.GetResponse();
            Stream responseStream = httpWebResponse.GetResponseStream();
            StreamReader streamReader = new StreamReader(responseStream, Encoding.UTF8);
            string html = streamReader.ReadToEnd();
            streamReader.Close();
            responseStream.Close();

            cookieCollection = cc.GetCookies(new Uri(url));

            return html;
        }

        public string GetHtml(string url)
        {
            CookieCollection cookieCollection;

            return GetHtml(url, out cookieCollection);
        }

        public string GetHtml(string url, string postData, Method method)
        {
            CookieCollection cookieCollection;

            return GetHtml(url, postData, method, out cookieCollection);
        }
        #endregion

    }
}
